@@ -220,23 +220,16 @@ void personal_gprs_mon_content_create (PersonalGprsMon *self)
 	gtk_container_set_border_width (GTK_CONTAINER (self->priv->contents), 0);
 	GtkSizeGroup *group = GTK_SIZE_GROUP (gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL));
 
-	//GtkWidget *image = gtk_image_new_from_icon_name ("personal-gprs-mon", GTK_ICON_SIZE_BUTTON);
-    //self->priv->titleLabel = gtk_label_new ("Dataplan Monitor");
-	//hildon_helper_set_logical_font (self->priv->titleLabel, "EmpSystemFont");
-	//GtkWidget *titleBox = gtk_hbox_new (FALSE, 0);
-	//gtk_container_set_border_width (GTK_CONTAINER (titleBox), 0);
-	//gtk_box_pack_start (GTK_BOX (titleBox), image, FALSE, FALSE, 0);
-	//gtk_box_pack_start (GTK_BOX (titleBox), self->priv->titleLabel, TRUE, TRUE, 0);
-	//gtk_misc_set_alignment (GTK_MISC (image), 0.5, 1);
-	//gtk_misc_set_padding (GTK_MISC (image), 2, 0);
-	//gtk_misc_set_alignment (GTK_MISC (self->priv->titleLabel), 0, 0.8);
-	
-	//self->priv->uploadLabel = gtk_label_new ("Uploaded");
-	self->priv->uploadLabel = gtk_image_new_from_icon_name ("personal-gprs-upload", GTK_ICON_SIZE_SMALL_TOOLBAR);
-	gtk_image_set_pixel_size (GTK_IMAGE (self->priv->uploadLabel), 26);
+	GtkIconTheme *iconTheme = gtk_icon_theme_get_default ();
+	if (gtk_icon_theme_has_icon (iconTheme, "personal-gprs-upload")) {
+		self->priv->uploadLabel = gtk_image_new_from_icon_name ("personal-gprs-upload", GTK_ICON_SIZE_SMALL_TOOLBAR);
+	} else {
+		self->priv->uploadLabel = gtk_image_new_from_file ("/usr/share/icons/hicolor/26x26/hildon/personal-gprs-upload.png");
+	}
+	gtk_image_set_pixel_size (GTK_IMAGE (self->priv->uploadLabel), 22);
 	//gtk_size_group_add_widget (group, self->priv->uploadLabel);
 	self->priv->uploadContent = gtk_label_new ("0.000 B");
-	gtk_label_set_markup (GTK_LABEL (self->priv->uploadContent), "0.<span gravity='north'>000</span> B");
+	gtk_label_set_markup (GTK_LABEL (self->priv->uploadContent), "0<small><sup>.000</sup></small> B");
 	GtkWidget *uploadBox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (uploadBox), self->priv->uploadLabel, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (uploadBox), self->priv->uploadContent, TRUE, TRUE, 0);
@@ -249,12 +242,15 @@ void personal_gprs_mon_content_create (PersonalGprsMon *self)
 	gtk_misc_set_padding (GTK_MISC (self->priv->uploadContent), HILDON_MARGIN_DEFAULT, HILDON_MARGIN_HALF);
 	gtk_box_pack_start (GTK_BOX (bigHBox), uploadBox, TRUE, TRUE, 0);
 	
-	//self->priv->downloadLabel = gtk_label_new ("Downloaded");
-	self->priv->downloadLabel = gtk_image_new_from_icon_name ("personal-gprs-download", GTK_ICON_SIZE_SMALL_TOOLBAR);
-	gtk_image_set_pixel_size (GTK_IMAGE (self->priv->downloadLabel), 26);
+	if (gtk_icon_theme_has_icon (iconTheme, "personal-gprs-download")) {
+		self->priv->downloadLabel = gtk_image_new_from_icon_name ("personal-gprs-download", GTK_ICON_SIZE_SMALL_TOOLBAR);
+	} else {
+		self->priv->downloadLabel = gtk_image_new_from_file ("/usr/share/icons/hicolor/26x26/hildon/personal-gprs-download.png");
+	}
+	gtk_image_set_pixel_size (GTK_IMAGE (self->priv->downloadLabel), 22);
 	//gtk_size_group_add_widget (group, self->priv->downloadLabel);
 	self->priv->downloadContent = gtk_label_new ("0.000 B");
-	gtk_label_set_markup (GTK_LABEL (self->priv->downloadContent), "0.<span gravity='north'>000</span> B");
+	gtk_label_set_markup (GTK_LABEL (self->priv->downloadContent), "0<small><sup>.000</sup></small> B");
 	GtkWidget *downloadBox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (downloadBox), self->priv->downloadLabel, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (downloadBox), self->priv->downloadContent, TRUE, TRUE, 0);	
@@ -419,9 +415,9 @@ gboolean personal_gprs_mon_update_content (PersonalGprsMon *self)
 	gint uploadRemainder = (gint) ((uploadSize - uploadInt) * pow (10, 3));
 	gint downloadRemainder = (gint) ((downloadSize - downloadInt) * pow (10, 3));
 	gtk_label_set_text (GTK_LABEL (self->priv->uploadContent), g_strdup_printf ("%d.%03d %s", uploadInt, uploadRemainder, uploadUnits));
-	gtk_label_set_markup (GTK_LABEL (self->priv->uploadContent), g_strdup_printf ("%d.<small><sup>%03d</sup></small> %s", uploadInt, uploadRemainder, uploadUnits));
+	gtk_label_set_markup (GTK_LABEL (self->priv->uploadContent), g_strdup_printf ("%d<small><sup>.%03d</sup></small> %s", uploadInt, uploadRemainder, uploadUnits));
 	gtk_label_set_text (GTK_LABEL (self->priv->downloadContent), g_strdup_printf ("%d.%03d %s", downloadInt, downloadRemainder, downloadUnits));
-	gtk_label_set_markup (GTK_LABEL (self->priv->downloadContent), g_strdup_printf ("%d.<small><sup>%03d</sup></small> %s", downloadInt, downloadRemainder, downloadUnits));
+	gtk_label_set_markup (GTK_LABEL (self->priv->downloadContent), g_strdup_printf ("%d<small><sup>.%03d</sup></small> %s", downloadInt, downloadRemainder, downloadUnits));
 
 	
 	if (self->priv->showResetDate) {
